@@ -1,8 +1,12 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+"""
+This module defines a class for a rectangular bounding box.
+"""
 
-import numpy as np
 from astropy.io.fits.util import _is_int
-
+from astropy.utils import deprecated
+from astropy.utils.decorators import deprecated_renamed_argument
+import numpy as np
 
 __all__ = ['BoundingBox']
 
@@ -70,7 +74,7 @@ class BoundingBox:
         self.iymax = iymax
 
     @classmethod
-    def _from_float(cls, xmin, xmax, ymin, ymax):
+    def from_float(cls, xmin, xmax, ymin, ymax):
         """
         Return the smallest bounding box that fully contains a given
         rectangle defined by float coordinate values.
@@ -104,10 +108,10 @@ class BoundingBox:
         Examples
         --------
         >>> from photutils import BoundingBox
-        >>> BoundingBox._from_float(xmin=1.0, xmax=10.0, ymin=2.0, ymax=20.0)
+        >>> BoundingBox.from_float(xmin=1.0, xmax=10.0, ymin=2.0, ymax=20.0)
         BoundingBox(ixmin=1, ixmax=11, iymin=2, iymax=21)
 
-        >>> BoundingBox._from_float(xmin=1.4, xmax=10.4, ymin=1.6, ymax=10.6)
+        >>> BoundingBox.from_float(xmin=1.4, xmax=10.4, ymin=1.6, ymax=10.6)
         BoundingBox(ixmin=1, ixmax=11, iymin=2, iymax=12)
         """
 
@@ -130,6 +134,12 @@ class BoundingBox:
             (self.iymax == other.iymax)
         )
 
+    def __or__(self, other):
+        return self.union(other)
+
+    def __and__(self, other):
+        return self.intersection(other)
+
     def __repr__(self):
         data = self.__dict__
         data['name'] = self.__class__.__name__
@@ -177,14 +187,34 @@ class BoundingBox:
             self.iymax - 0.5,
         )
 
-    def as_patch(self, **kwargs):
+    @deprecated('0.7', alternative='as_artist')
+    def as_patch(self, **kwargs):  # pragma: no cover
         """
         Return a `matplotlib.patches.Rectangle` that represents the
         bounding box.
 
         Parameters
         ----------
-        kwargs
+        kwargs : `dict`
+            Any keyword arguments accepted by
+            `matplotlib.patches.Patch`.
+
+        Returns
+        -------
+        result : `matplotlib.patches.Rectangle`
+            A matplotlib rectangular patch.
+        """
+
+        return self.as_artist(**kwargs)
+
+    def as_artist(self, **kwargs):
+        """
+        Return a `matplotlib.patches.Rectangle` that represents the
+        bounding box.
+
+        Parameters
+        ----------
+        kwargs : `dict`
             Any keyword arguments accepted by
             `matplotlib.patches.Patch`.
 
@@ -206,7 +236,7 @@ class BoundingBox:
             np.random.seed(12345)
             ax.imshow(np.random.random((10, 10)), interpolation='nearest',
                       cmap='viridis')
-            ax.add_patch(bbox.as_patch(facecolor='none', edgecolor='white',
+            ax.add_patch(bbox.as_artist(facecolor='none', edgecolor='white',
                          lw=2.))
         """
 
@@ -221,37 +251,92 @@ class BoundingBox:
         represents the bounding box.
         """
 
-        from .rectangle import RectangularAperture
+        from .rectangle import RectangularAperture  # prevent circular import
 
         xpos = (self.extent[1] + self.extent[0]) / 2.
         ypos = (self.extent[3] + self.extent[2]) / 2.
         xypos = (xpos, ypos)
-        h, w = self.shape
+        height, width = self.shape
 
-        return RectangularAperture(xypos, w=w, h=h, theta=0.)
+        return RectangularAperture(xypos, w=width, h=height, theta=0.)
 
-    def plot(self, origin=(0, 0), ax=None, fill=False, **kwargs):
+    @deprecated_renamed_argument('ax', 'axes', '0.7')
+    def plot(self, axes=None, origin=(0, 0), **kwargs):
         """
         Plot the `BoundingBox` on a matplotlib `~matplotlib.axes.Axes`
         instance.
 
         Parameters
         ----------
+        axes : `matplotlib.axes.Axes` or `None`, optional
+            The matplotlib axes on which to plot.  If `None`, then the
+            current `~matplotlib.axes.Axes` instance is used.
+
         origin : array_like, optional
             The ``(x, y)`` position of the origin of the displayed
             image.
 
-        ax : `matplotlib.axes.Axes` instance, optional
-            If `None`, then the current `~matplotlib.axes.Axes` instance
-            is used.
-
-        fill : bool, optional
-            Set whether to fill the aperture patch.  The default is
-            `False`.
-
-        kwargs
+        kwargs : `dict`
             Any keyword arguments accepted by `matplotlib.patches.Patch`.
         """
 
         aper = self.to_aperture()
-        aper.plot(origin=origin, ax=ax, fill=fill, **kwargs)
+        aper.plot(axes=axes, origin=origin, **kwargs)
+
+    def union(self, other):
+        """
+        Return a `BoundingBox` representing the union of this
+        `BoundingBox` with another `BoundingBox`.
+
+        Parameters
+        ----------
+        other : `~photutils.BoundingBox`
+            The `BoundingBox` to join with this one.
+
+        Returns
+        -------
+        result : `~photutils.BoundingBox`
+            A `BoundingBox` representing the union of the input
+            `BoundingBox` with this one.
+        """
+
+        if not isinstance(other, BoundingBox):
+            raise TypeError('BoundingBox can be joined only with another '
+                            'BoundingBox.')
+
+        ixmin = min((self.ixmin, other.ixmin))
+        ixmax = max((self.ixmax, other.ixmax))
+        iymin = min((self.iymin, other.iymin))
+        iymax = max((self.iymax, other.iymax))
+
+        return BoundingBox(ixmin=ixmin, ixmax=ixmax, iymin=iymin, iymax=iymax)
+
+    def intersection(self, other):
+        """
+        Return a `BoundingBox` representing the intersection of this
+        `BoundingBox` with another `BoundingBox`.
+
+        Parameters
+        ----------
+        other : `~photutils.BoundingBox`
+            The `BoundingBox` to intersect with this one.
+
+        Returns
+        -------
+        result : `~photutils.BoundingBox`
+            A `BoundingBox` representing the intersection of the input
+            `BoundingBox` with this one.
+        """
+
+        if not isinstance(other, BoundingBox):
+            raise TypeError('BoundingBox can be intersected only with '
+                            'another BoundingBox.')
+
+        ixmin = max(self.ixmin, other.ixmin)
+        ixmax = min(self.ixmax, other.ixmax)
+        iymin = max(self.iymin, other.iymin)
+        iymax = min(self.iymax, other.iymax)
+        if ixmax < ixmin or iymax < iymin:
+            return None
+
+        return BoundingBox(ixmin=ixmin, ixmax=ixmax, iymin=iymin, iymax=iymax)
