@@ -1,19 +1,22 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+"""
+Tests for the core module.
+"""
 
 import itertools
 
+from astropy.modeling.models import Gaussian1D, Gaussian2D
 import numpy as np
 from numpy.testing import assert_allclose
-from astropy.modeling.models import Gaussian1D, Gaussian2D
 import pytest
 
-from ..core import (centroid_com, centroid_1dg, centroid_2dg,
-                    gaussian1d_moments, fit_2dgaussian)
-
+from ..core import (centroid_1dg, centroid_2dg, centroid_com, centroid_epsf,
+                    fit_2dgaussian, gaussian1d_moments)
+from ...psf import IntegratedGaussianPRF
 
 try:
     # the fitting routines in astropy use scipy.optimize
-    import scipy    # noqa
+    import scipy  # noqa
     HAS_SCIPY = True
 except ImportError:
     HAS_SCIPY = False
@@ -68,13 +71,35 @@ def test_centroids_witherror(xc_ref, yc_ref, x_stddev, y_stddev, theta):
     assert_allclose([xc_ref, yc_ref], [xc3, yc3], rtol=0, atol=1.e-3)
 
 
+@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.parametrize(
+    ('xc_ref', 'yc_ref', 'x_stddev', 'y_stddev', 'theta'),
+    list(itertools.product(XCS, YCS, XSTDDEVS, YSTDDEVS, THETAS)))
+def test_centroids_oversampling(xc_ref, yc_ref, x_stddev, y_stddev, theta):
+    model = Gaussian2D(2.4, xc_ref, yc_ref, x_stddev=x_stddev,
+                       y_stddev=y_stddev, theta=theta)
+    y, x = np.mgrid[0:50, 0:50]
+    data = model(x, y)
+    mask = np.zeros(data.shape, dtype=bool)
+    data[10, 10] = 1.e5
+    mask[10, 10] = True
+    for oversampling in [4, (4, 6)]:
+        if not hasattr(oversampling, '__len__'):
+            _oversampling = (oversampling, oversampling)
+        else:
+            _oversampling = oversampling
+        xc, yc = centroid_com(data, mask=mask, oversampling=oversampling)
+        assert_allclose([xc, yc], [xc_ref / _oversampling[0], yc_ref / _oversampling[1]],
+                        rtol=0, atol=1.e-3)
+
+
 @pytest.mark.skipif('not HAS_SCIPY')
 def test_centroids_withmask():
     xc_ref, yc_ref = 24.7, 25.2
     model = Gaussian2D(2.4, xc_ref, yc_ref, x_stddev=5.0, y_stddev=5.0)
     y, x = np.mgrid[0:50, 0:50]
     data = model(x, y)
-    mask = np.zeros_like(data, dtype=bool)
+    mask = np.zeros(data.shape, dtype=bool)
     data[10, 10] = 1.e5
     mask[10, 10] = True
 
@@ -109,7 +134,7 @@ def test_centroids_nan_withmask(use_mask):
     data = model(x, y)
     data[20, :] = np.nan
     if use_mask:
-        mask = np.zeros_like(data, dtype=bool)
+        mask = np.zeros(data.shape, dtype=bool)
         mask[20, :] = True
     else:
         mask = None
@@ -183,13 +208,13 @@ def test_gaussian1d_moments():
     assert_allclose(result, desired, rtol=0, atol=1.e-6)
 
     data[0] = 1.e5
-    mask = np.zeros_like(data).astype(bool)
+    mask = np.zeros(data.shape).astype(bool)
     mask[0] = True
     result = gaussian1d_moments(data, mask=mask)
     assert_allclose(result, desired, rtol=0, atol=1.e-6)
 
     data[0] = np.nan
-    mask = np.zeros_like(data).astype(bool)
+    mask = np.zeros(data.shape).astype(bool)
     mask[0] = True
     result = gaussian1d_moments(data, mask=mask)
     assert_allclose(result, desired, rtol=0, atol=1.e-6)
@@ -200,3 +225,51 @@ def test_fit2dgaussian_dof():
     data = np.ones((2, 2))
     with pytest.raises(ValueError):
         fit_2dgaussian(data)
+
+
+@pytest.mark.skipif('not HAS_SCIPY')
+def test_centroid_epsf():
+    sigma = 0.5
+    psf = IntegratedGaussianPRF(sigma=sigma)
+    for oversampling in [4, (4, 6)]:
+        if not hasattr(oversampling, '__len__'):
+            _oversampling = (oversampling, oversampling)
+        else:
+            _oversampling = oversampling
+        x = np.arange(1 + 25 * _oversampling[0]) / _oversampling[0]
+        x0 = x[-1] / 2
+        x -= x0
+        y = np.arange(1 + 25 * _oversampling[1]) / _oversampling[1]
+        y0 = y[-1] / 2
+        y -= y0
+        offsets = np.array([0.1, 0.03])
+        data = psf.evaluate(x=x.reshape(1, -1), y=y.reshape(-1, 1), flux=1, x_0=offsets[0],
+                            y_0=offsets[1], sigma=sigma)
+
+        mask = np.zeros(data.shape, np.bool)
+        mask[0, 0] = 1
+        centers = centroid_epsf(data, mask=mask, oversampling=oversampling)
+        assert_allclose(centers, offsets+x0, rtol=1e-3, atol=1e-2)
+
+
+def test_centroid_exceptions():
+    data = np.ones((5, 5), dtype=float)
+    mask = np.zeros((4, 5), dtype=int)
+    mask[2, 2] = 1
+
+    # Test data and mask having the same shape
+    with pytest.raises(ValueError):
+        centroid_epsf(data, mask)
+
+    with pytest.raises(ValueError):
+        centroid_epsf(data, shift_val=-1)
+
+    with pytest.raises(ValueError):
+        centroid_epsf(data, oversampling=-1)
+    with pytest.raises(ValueError):
+        centroid_com(data, oversampling=-1)
+
+    data = np.ones((21, 21), dtype=float)
+    data[10, 10] = np.inf
+    with pytest.raises(ValueError):
+        centroid_epsf(data)
