@@ -1,7 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """
 This module implements classes for detecting stars in an astronomical
-image. The convention is that all star-finding classes are subclasses of
+image.  The convention is that all star-finding classes are subclasses of
 an abstract base class called ``StarFinderBase``.  Each star-finding
 class should define a method called ``find_stars`` that finds stars in
 an image.
@@ -11,17 +11,15 @@ import abc
 import math
 import warnings
 
-import numpy as np
 from astropy.stats import gaussian_fwhm_to_sigma
 from astropy.table import Table
-from astropy.utils.exceptions import AstropyUserWarning
 from astropy.utils import lazyproperty
+import numpy as np
 
 from .core import find_peaks
 from ..utils._moments import _moments, _moments_central
-from ..utils.convolution import filter_data
-from ..utils.misc import _ABCMetaAndInheritDocstrings
-
+from ..utils.convolution import _filter_data
+from ..utils.exceptions import NoDetectionsWarning
 
 __all__ = ['StarFinderBase', 'DAOStarFinder', 'IRAFStarFinder']
 
@@ -152,8 +150,6 @@ class _StarFinderKernel:
 
         self.shape = self.data.shape
 
-        return
-
 
 class _StarCutout:
     """
@@ -197,20 +193,20 @@ class _StarCutout:
         self.threshold_eff = threshold_eff
 
         self.shape = data.shape
-        self.nx = self.shape[1]    # always odd
-        self.ny = self.shape[0]    # always odd
+        self.nx = self.shape[1]  # always odd
+        self.ny = self.shape[0]  # always odd
         self.cutout_xcenter = int(self.nx // 2)
         self.cutout_ycenter = int(self.ny // 2)
 
-        self.xorigin = self.slices[1].start    # in original image
-        self.yorigin = self.slices[0].start    # in original image
+        self.xorigin = self.slices[1].start  # in original image
+        self.yorigin = self.slices[0].start  # in original image
 
-        self.mask = kernel.mask    # kernel mask
-        self.npixels = kernel.npixels    # unmasked pixels
+        self.mask = kernel.mask  # kernel mask
+        self.npixels = kernel.npixels  # unmasked pixels
         self.data_masked = self.data * self.mask
 
 
-class _DAOFind_Properties:
+class _DAOFindProperties:
     """
     Class to calculate the properties of each detected star, as defined
     by `DAOFIND`_.
@@ -241,11 +237,11 @@ class _DAOFind_Properties:
 
         self.cutout = star_cutout
         self.kernel = kernel
-        self.sky = sky    # DAOFIND has no sky input -> same as sky=0.
+        self.sky = sky  # DAOFIND has no sky input -> same as sky=0.
 
         self.data = star_cutout.data
         self.data_masked = star_cutout.data_masked
-        self.npixels = star_cutout.npixels    # unmasked pixels
+        self.npixels = star_cutout.npixels  # unmasked pixels
         self.nx = star_cutout.nx
         self.ny = star_cutout.ny
         self.xcenter = star_cutout.cutout_xcenter
@@ -283,7 +279,7 @@ class _DAOFind_Properties:
 
     @lazyproperty
     def sharpness(self):
-        npixels = self.npixels - 1    # exclude the peak pixel
+        npixels = self.npixels - 1  # exclude the peak pixel
         data_mean = (np.sum(self.data_masked) - self.data_peak) / npixels
 
         return (self.data_peak - data_mean) / self.conv_peak
@@ -323,16 +319,16 @@ class _DAOFind_Properties:
         y = self.ycenter - np.abs(np.arange(self.ny) - self.ycenter) + 1
         xwt, ywt = np.meshgrid(x, y)
 
-        if axis == 0:    # marginal distributions along x axis
-            wt = xwt[0]    # 1D
-            wts = ywt    # 2D
+        if axis == 0:  # marginal distributions along x axis
+            wt = xwt[0]  # 1D
+            wts = ywt  # 2D
             size = self.nx
             center = self.xcenter
             sigma = self.kernel.xsigma
             dxx = center - np.arange(size)
-        elif axis == 1:    # marginal distributions along y axis
-            wt = np.transpose(ywt)[0]    # 1D
-            wts = xwt    # 2D
+        elif axis == 1:  # marginal distributions along y axis
+            wt = np.transpose(ywt)[0]  # 1D
+            wts = xwt  # 2D
             size = self.ny
             center = self.ycenter
             sigma = self.kernel.ysigma
@@ -465,7 +461,7 @@ class _DAOFind_Properties:
             return -2.5 * np.log10(self.flux)
 
 
-class _IRAFStarFind_Properties:
+class _IRAFStarFindProperties:
     """
     Class to calculate the properties of each detected star, as defined
     by IRAF's ``starfind`` task.
@@ -496,7 +492,7 @@ class _IRAFStarFind_Properties:
         self.kernel = kernel
 
         if sky is None:
-            skymask = ~self.kernel.mask.astype(np.bool)   # 1=sky, 0=obj
+            skymask = ~self.kernel.mask.astype(np.bool)  # 1=sky, 0=obj
             nsky = np.count_nonzero(skymask)
             if nsky == 0:
                 mean_sky = (np.max(self.cutout.data) -
@@ -631,11 +627,11 @@ def _find_stars(data, kernel, threshold_eff, min_separation=None,
     .. _starfind: http://stsdas.stsci.edu/cgi-bin/gethelp.cgi?starfind
     """
 
-    convolved_data = filter_data(data, kernel.data, mode='constant',
-                                 fill_value=0.0, check_normalization=False)
+    convolved_data = _filter_data(data, kernel.data, mode='constant',
+                                  fill_value=0.0, check_normalization=False)
 
     # define a local footprint for the peak finder
-    if min_separation is None:   # daofind
+    if min_separation is None:  # daofind
         footprint = kernel.mask.astype(np.bool)
     else:
         # define a circular footprint
@@ -659,10 +655,14 @@ def _find_stars(data, kernel, threshold_eff, min_separation=None,
                                 constant_values=[0.])
 
     # find local peaks in the convolved data
-    tbl = find_peaks(convolved_data, threshold_eff, footprint=footprint,
-                     mask=mask)
-    if len(tbl) == 0:
-        return []
+    with warnings.catch_warnings():
+        # suppress any NoDetectionsWarning from find_peaks
+        warnings.filterwarnings('ignore', category=NoDetectionsWarning)
+        tbl = find_peaks(convolved_data, threshold_eff, footprint=footprint,
+                         mask=mask)
+
+    if tbl is None:
+        return None
 
     coords = np.transpose([tbl['y_peak'], tbl['x_peak']])
 
@@ -676,9 +676,9 @@ def _find_stars(data, kernel, threshold_eff, min_separation=None,
         y1 = ypeak + kernel.yradius + 1
 
         if x0 < 0 or x1 > data.shape[1]:
-            continue    # pragma: no cover
+            continue  # pragma: no cover
         if y0 < 0 or y1 > data.shape[0]:
-            continue    # pragma: no cover
+            continue  # pragma: no cover
 
         slices = (slice(y0, y1), slice(x0, x1))
         data_cutout = data[slices]
@@ -700,7 +700,7 @@ def _find_stars(data, kernel, threshold_eff, min_separation=None,
     return star_cutouts
 
 
-class StarFinderBase(metaclass=_ABCMetaAndInheritDocstrings):
+class StarFinderBase(metaclass=abc.ABCMeta):
     """
     Abstract base class for star finders.
     """
@@ -889,6 +889,7 @@ class DAOStarFinder(StarFinderBase):
         self.threshold_eff = self.threshold * self.kernel.relerr
         self.brightest = brightest
         self.peakmax = peakmax
+        self._star_cutouts = None
 
     def find_stars(self, data, mask=None):
         """
@@ -907,7 +908,7 @@ class DAOStarFinder(StarFinderBase):
 
         Returns
         -------
-        table : `~astropy.table.Table`
+        table : `~astropy.table.Table` or `None`
             A table of found stars with the following parameters:
 
             * ``id``: unique object identification number.
@@ -927,29 +928,23 @@ class DAOStarFinder(StarFinderBase):
               ``-2.5 * log10(flux)``.  The derivation matches that of
               `DAOFIND`_ if ``sky`` is 0.0.
 
-            If no stars are found then an empty table is returned.
+            `None` is returned if no stars are found.
 
-        .. _DAOFIND: http://stsdas.stsci.edu/cgi-bin/gethelp.cgi?daofind
         """
 
         star_cutouts = _find_stars(data, self.kernel, self.threshold_eff,
                                    mask=mask,
                                    exclude_border=self.exclude_border)
+
+        if star_cutouts is None:
+            warnings.warn('No sources were found.', NoDetectionsWarning)
+            return None
+
         self._star_cutouts = star_cutouts
 
-        columns = ('id', 'xcentroid', 'ycentroid', 'sharpness', 'roundness1',
-                   'roundness2', 'npix', 'sky', 'peak', 'flux', 'mag')
-        coltypes = (np.int_, np.float_, np.float_, np.float_, np.float_,
-                    np.float_, np.int_, np.float_, np.float_, np.float_,
-                    np.float_)
-
-        if len(star_cutouts) == 0:
-            warnings.warn('No sources were found.', AstropyUserWarning)
-            return Table(names=columns, dtype=coltypes)
-
         star_props = []
         for star_cutout in star_cutouts:
-            props = _DAOFind_Properties(star_cutout, self.kernel, self.sky)
+            props = _DAOFindProperties(star_cutout, self.kernel, self.sky)
 
             if np.isnan(props.dx_hx).any() or np.isnan(props.dy_hy).any():
                 continue
@@ -974,8 +969,8 @@ class DAOStarFinder(StarFinderBase):
         nstars = len(star_props)
         if nstars == 0:
             warnings.warn('Sources were found, but none pass the sharpness '
-                          'and roundness criteria.', AstropyUserWarning)
-            return Table(names=columns, dtype=coltypes)
+                          'and roundness criteria.', NoDetectionsWarning)
+            return None
 
         if self.brightest is not None:
             fluxes = [props.flux for props in star_props]
@@ -985,7 +980,9 @@ class DAOStarFinder(StarFinderBase):
 
         table = Table()
         table['id'] = np.arange(nstars) + 1
-        for column in columns[1:]:
+        columns = ('xcentroid', 'ycentroid', 'sharpness', 'roundness1',
+                   'roundness2', 'npix', 'sky', 'peak', 'flux', 'mag')
+        for column in columns:
             table[column] = [getattr(props, column) for props in star_props]
 
         return table
@@ -1121,6 +1118,7 @@ class IRAFStarFinder(StarFinderBase):
                                         sigma_radius=self.sigma_radius)
         self.brightest = brightest
         self.peakmax = peakmax
+        self._star_cutouts = None
 
     def find_stars(self, data, mask=None):
         """
@@ -1139,7 +1137,7 @@ class IRAFStarFinder(StarFinderBase):
 
         Returns
         -------
-        table : `~astropy.table.Table`
+        table : `~astropy.table.Table` or `None`
             A table of found objects with the following parameters:
 
             * ``id``: unique object identification number.
@@ -1156,31 +1154,25 @@ class IRAFStarFinder(StarFinderBase):
             * ``mag``: the object instrumental magnitude calculated as
               ``-2.5 * log10(flux)``.
 
-            If no stars are found then an empty table is returned.
+            `None` is returned if no stars are found.
 
-        .. _starfind: http://stsdas.stsci.edu/cgi-bin/gethelp.cgi?starfind
         """
 
         star_cutouts = _find_stars(data, self.kernel, self.threshold,
                                    min_separation=self.min_separation,
                                    mask=mask,
                                    exclude_border=self.exclude_border)
+
+        if star_cutouts is None:
+            warnings.warn('No sources were found.', NoDetectionsWarning)
+            return None
+
         self._star_cutouts = star_cutouts
 
-        columns = ('id', 'xcentroid', 'ycentroid', 'fwhm', 'sharpness',
-                   'roundness', 'pa', 'npix', 'sky', 'peak', 'flux', 'mag')
-        coltypes = (np.int_, np.float_, np.float_, np.float_, np.float_,
-                    np.float_, np.float_, np.int_, np.float_, np.float_,
-                    np.float_, np.float_)
-
-        if len(star_cutouts) == 0:
-            warnings.warn('No sources were found.', AstropyUserWarning)
-            return Table(names=columns, dtype=coltypes)
-
         star_props = []
         for star_cutout in star_cutouts:
-            props = _IRAFStarFind_Properties(star_cutout, self.kernel,
-                                             self.sky)
+            props = _IRAFStarFindProperties(star_cutout, self.kernel,
+                                            self.sky)
 
             # star cutout needs more than one non-zero value
             if np.count_nonzero(props.data) <= 1:
@@ -1202,8 +1194,8 @@ class IRAFStarFinder(StarFinderBase):
         nstars = len(star_props)
         if nstars == 0:
             warnings.warn('Sources were found, but none pass the sharpness '
-                          'and roundness criteria.', AstropyUserWarning)
-            return Table(names=columns, dtype=coltypes)
+                          'and roundness criteria.', NoDetectionsWarning)
+            return None
 
         if self.brightest is not None:
             fluxes = [props.flux for props in star_props]
@@ -1213,7 +1205,9 @@ class IRAFStarFinder(StarFinderBase):
 
         table = Table()
         table['id'] = np.arange(nstars) + 1
-        for column in columns[1:]:
+        columns = ('xcentroid', 'ycentroid', 'fwhm', 'sharpness', 'roundness',
+                   'pa', 'npix', 'sky', 'peak', 'flux', 'mag')
+        for column in columns:
             table[column] = [getattr(props, column) for props in star_props]
 
         return table
