@@ -1,6 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+"""
+Tests for the core module.
+"""
 
 import numpy as np
 from numpy.testing import assert_allclose
@@ -9,7 +10,7 @@ import pytest
 from ..core import data_properties
 
 try:
-    import skimage    # noqa
+    import skimage  # noqa
     HAS_SKIMAGE = True
 except ImportError:
     HAS_SKIMAGE = False
@@ -33,7 +34,7 @@ def test_data_properties():
     props = data_properties(data, mask=None)
     props2 = data_properties(data, mask=mask)
     properties = ['xcentroid', 'ycentroid', 'area']
-    result = [props[i].value for i in properties]
-    result2 = [props2[i].value for i in properties]
+    result = [getattr(props, i).value for i in properties]
+    result2 = [getattr(props2, i).value for i in properties]
     assert_allclose([0.5, 0.5, 4.0], result, rtol=0, atol=1.e-6)
     assert_allclose([0.5, 0.0, 2.0], result2, rtol=0, atol=1.e-6)
