@@ -1,18 +1,17 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-"""Module which provides classes to perform source grouping."""
+"""
+This module provides classes to perform grouping of stars.
+"""
 
 import abc
 
-import numpy as np
 from astropy.table import Column
-
-from ..utils.misc import _ABCMetaAndInheritDocstrings
-
+import numpy as np
 
 __all__ = ['DAOGroup', 'DBSCANGroup', 'GroupStarsBase']
 
 
-class GroupStarsBase(metaclass=_ABCMetaAndInheritDocstrings):
+class GroupStarsBase(metaclass=abc.ABCMeta):
     """
     This base class provides the basic interface for subclasses that
     are capable of classifying stars in groups.
