@@ -1,18 +1,29 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+"""
+Tests for the groupstars module.
+"""
 
-import numpy as np
-import pytest
-from numpy.testing import assert_array_equal
 from astropy.table import Table, vstack
+import numpy as np
+from numpy.testing import assert_almost_equal
+import pytest
+
 from ..groupstars import DAOGroup, DBSCANGroup
 
 try:
-    import sklearn.cluster    # noqa
+    import sklearn.cluster  # noqa
     HAS_SKLEARN = True
 except ImportError:
     HAS_SKLEARN = False
 
 
+def assert_table_almost_equal(table1, table2):
+    assert table1.colnames == table2.colnames
+    assert table1.meta == table2.meta
+    for colname in table1.colnames:
+        assert_almost_equal(table1[colname], table2[colname])
+
+
 class TestDAOGROUP:
     def test_daogroup_one(self):
         """
@@ -51,7 +62,7 @@ class TestDAOGROUP:
         starlist = vstack([first_group, second_group])
         daogroup = DAOGroup(crit_separation=0.6)
         test_starlist = daogroup(starlist['x_0', 'y_0', 'id'])
-        assert_array_equal(starlist, test_starlist)
+        assert_table_almost_equal(starlist, test_starlist)
 
     def test_daogroup_two(self):
         """
@@ -82,7 +93,7 @@ class TestDAOGROUP:
         starlist = vstack([first_group, second_group])
         daogroup = DAOGroup(crit_separation=0.3)
         test_starlist = daogroup(starlist['x_0', 'y_0', 'id'])
-        assert_array_equal(starlist, test_starlist)
+        assert_table_almost_equal(starlist, test_starlist)
 
     def test_daogroup_three(self):
         """
@@ -113,7 +124,7 @@ class TestDAOGROUP:
         starlist = vstack([first_group, second_group])
         daogroup = DAOGroup(crit_separation=0.3)
         test_starlist = daogroup(starlist['x_0', 'y_0', 'id'])
-        assert_array_equal(starlist, test_starlist)
+        assert_table_almost_equal(starlist, test_starlist)
 
     def test_daogroup_four(self):
         """
@@ -147,7 +158,7 @@ class TestDAOGROUP:
                          names=('x_0', 'y_0', 'id', 'group_id'))
         daogroup = DAOGroup(crit_separation=2.5)
         test_starlist = daogroup(starlist['x_0', 'y_0', 'id'])
-        assert_array_equal(starlist, test_starlist)
+        assert_table_almost_equal(starlist, test_starlist)
 
     def test_daogroup_five(self):
         """
@@ -185,7 +196,7 @@ class TestDAOGROUP:
                            fourth_group])
         daogroup = DAOGroup(crit_separation=0.3)
         test_starlist = daogroup(starlist['x_0', 'y_0', 'id'])
-        assert_array_equal(starlist, test_starlist)
+        assert_table_almost_equal(starlist, test_starlist)
 
     def test_daogroup_six(self):
         """
@@ -225,7 +236,7 @@ class TestDAOGROUP:
         starlist = vstack([first_group, second_group, third_group])
         daogroup = DAOGroup(crit_separation=0.6)
         test_starlist = daogroup(starlist['x_0', 'y_0', 'id'])
-        assert_array_equal(starlist, test_starlist)
+        assert_table_almost_equal(starlist, test_starlist)
 
     def test_isolated_sources(self):
         """
@@ -240,7 +251,7 @@ class TestDAOGROUP:
                          names=('x_0', 'y_0', 'id', 'group_id'))
         daogroup = DAOGroup(crit_separation=0.01)
         test_starlist = daogroup(starlist['x_0', 'y_0', 'id'])
-        assert_array_equal(starlist, test_starlist)
+        assert_table_almost_equal(starlist, test_starlist)
 
     def test_id_column(self):
         x_0 = np.array([0, np.sqrt(2)/4, np.sqrt(2)/4, -np.sqrt(2)/4,
@@ -252,7 +263,7 @@ class TestDAOGROUP:
                          names=('x_0', 'y_0', 'id', 'group_id'))
         daogroup = DAOGroup(crit_separation=0.01)
         test_starlist = daogroup(starlist['x_0', 'y_0'])
-        assert_array_equal(starlist, test_starlist)
+        assert_table_almost_equal(starlist, test_starlist)
 
     def test_id_column_raise_error(self):
         x_0 = np.array([0, np.sqrt(2)/4, np.sqrt(2)/4, -np.sqrt(2)/4,
@@ -284,7 +295,7 @@ class TestDBSCANGroup:
         starlist = vstack([first_group, second_group])
         dbscan = DBSCANGroup(crit_separation=0.6)
         test_starlist = dbscan(starlist['x_0', 'y_0', 'id'])
-        assert_array_equal(starlist, test_starlist)
+        assert_table_almost_equal(starlist, test_starlist)
 
     def test_group_stars_two(object):
         first_group = Table([1.5*np.ones(5), np.linspace(0, 1, 5),
@@ -303,7 +314,7 @@ class TestDBSCANGroup:
                            fourth_group])
         dbscan = DBSCANGroup(crit_separation=0.3)
         test_starlist = dbscan(starlist['x_0', 'y_0', 'id'])
-        assert_array_equal(starlist, test_starlist)
+        assert_table_almost_equal(starlist, test_starlist)
 
     def test_isolated_sources(self):
         """
@@ -318,7 +329,7 @@ class TestDBSCANGroup:
                          names=('x_0', 'y_0', 'id', 'group_id'))
         dbscan = DBSCANGroup(crit_separation=0.01)
         test_starlist = dbscan(starlist['x_0', 'y_0', 'id'])
-        assert_array_equal(starlist, test_starlist)
+        assert_table_almost_equal(starlist, test_starlist)
 
     def test_id_column(self):
         x_0 = np.array([0, np.sqrt(2)/4, np.sqrt(2)/4, -np.sqrt(2)/4,
@@ -330,7 +341,7 @@ class TestDBSCANGroup:
                          names=('x_0', 'y_0', 'id', 'group_id'))
         dbscan = DBSCANGroup(crit_separation=0.01)
         test_starlist = dbscan(starlist['x_0', 'y_0'])
-        assert_array_equal(starlist, test_starlist)
+        assert_table_almost_equal(starlist, test_starlist)
 
     def test_id_column_raise_error(self):
         x_0 = np.array([0, np.sqrt(2)/4, np.sqrt(2)/4, -np.sqrt(2)/4,
