@@ -1,30 +1,32 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-
-import pytest
-import numpy as np
-from numpy.testing import assert_allclose, assert_array_equal, assert_equal
+"""
+Tests for the photometry module.
+"""
 
 from astropy.convolution.utils import discretize_model
-from astropy.modeling import Parameter, Fittable2DModel
+from astropy.modeling import Fittable2DModel, Parameter
 from astropy.modeling.fitting import LevMarLSQFitter
 from astropy.modeling.models import Gaussian2D, Moffat2D
-from astropy.stats import gaussian_sigma_to_fwhm, SigmaClip
+from astropy.stats import SigmaClip, gaussian_sigma_to_fwhm
 from astropy.table import Table
 from astropy.tests.helper import catch_warnings
 from astropy.utils.exceptions import AstropyUserWarning
+import numpy as np
+from numpy.testing import assert_allclose, assert_array_equal, assert_equal
+import pytest
 
 from ..groupstars import DAOGroup
 from ..models import IntegratedGaussianPRF
-from ..photometry import (DAOPhotPSFPhotometry, BasicPSFPhotometry,
+from ..photometry import (BasicPSFPhotometry, DAOPhotPSFPhotometry,
                           IterativelySubtractedPSFPhotometry)
 from ..sandbox import DiscretePRF
 from ..utils import prepare_psf_model
-from ...background import StdBackgroundRMS, MMMBackground
-from ...datasets import make_gaussian_sources_image, make_noise_image
+from ...background import MMMBackground, StdBackgroundRMS
+from ...datasets import make_gaussian_prf_sources_image, make_noise_image
 from ...detection import DAOStarFinder
 
 try:
-    import scipy    # noqa
+    import scipy  # noqa
     HAS_SCIPY = True
 except ImportError:
     HAS_SCIPY = False
@@ -77,10 +79,9 @@ sigma_psfs = []
 sigma_psfs.append(2)
 sources1 = Table()
 sources1['flux'] = [800, 1000, 1200]
-sources1['x_mean'] = [13, 18, 25]
-sources1['y_mean'] = [16, 16, 25]
-sources1['x_stddev'] = [sigma_psfs[-1]] * 3
-sources1['y_stddev'] = sources1['x_stddev']
+sources1['x_0'] = [13, 18, 25]
+sources1['y_0'] = [16, 16, 25]
+sources1['sigma'] = [sigma_psfs[-1]] * 3
 sources1['theta'] = [0] * 3
 sources1['id'] = [1, 2, 3]
 sources1['group_id'] = [1, 1, 2]
@@ -90,10 +91,9 @@ sources1['group_id'] = [1, 1, 2]
 sigma_psfs.append(2)
 sources2 = Table()
 sources2['flux'] = [700, 800, 700, 800]
-sources2['x_mean'] = [12, 17, 12, 17]
-sources2['y_mean'] = [15, 15, 20, 20]
-sources2['x_stddev'] = [sigma_psfs[-1]] * 4
-sources2['y_stddev'] = sources2['x_stddev']
+sources2['x_0'] = [12, 17, 12, 17]
+sources2['y_0'] = [15, 15, 20, 20]
+sources2['sigma'] = [sigma_psfs[-1]] * 4
 sources2['theta'] = [0] * 4
 sources2['id'] = [1, 2, 3, 4]
 sources2['group_id'] = [1, 1, 1, 1]
@@ -105,10 +105,9 @@ sources2['group_id'] = [1, 1, 1, 1]
 sigma_psfs.append(2)
 sources3 = Table()
 sources3['flux'] = [10000, 1000]
-sources3['x_mean'] = [18, 13]
-sources3['y_mean'] = [17, 19]
-sources3['x_stddev'] = [sigma_psfs[-1]] * 2
-sources3['y_stddev'] = sources3['x_stddev']
+sources3['x_0'] = [18, 13]
+sources3['y_0'] = [17, 19]
+sources3['sigma'] = [sigma_psfs[-1]] * 2
 sources3['theta'] = [0] * 2
 sources3['id'] = [1] * 2
 sources3['group_id'] = [1] * 2
@@ -121,10 +120,10 @@ def test_psf_photometry_niters(sigma_psf, sources):
     img_shape = (32, 32)
     # generate image with read-out noise (Gaussian) and
     # background noise (Poisson)
-    image = (make_gaussian_sources_image(img_shape, sources) +
-             make_noise_image(img_shape, type='poisson', mean=6.,
+    image = (make_gaussian_prf_sources_image(img_shape, sources) +
+             make_noise_image(img_shape, distribution='poisson', mean=6.,
                               random_state=1) +
-             make_noise_image(img_shape, type='gaussian', mean=0.,
+             make_noise_image(img_shape, distribution='gaussian', mean=0.,
                               stddev=2., random_state=1))
     cp_image = image.copy()
     sigma_clip = SigmaClip(sigma=3.)
@@ -145,8 +144,8 @@ def test_psf_photometry_niters(sigma_psf, sources):
         assert (result_tab['flux_unc'] < 1.96 *
                 np.sqrt(sources['flux'])).all()
 
-        assert_allclose(result_tab['x_fit'], sources['x_mean'], rtol=1e-1)
-        assert_allclose(result_tab['y_fit'], sources['y_mean'], rtol=1e-1)
+        assert_allclose(result_tab['x_fit'], sources['x_0'], rtol=1e-1)
+        assert_allclose(result_tab['y_fit'], sources['y_0'], rtol=1e-1)
         assert_allclose(result_tab['flux_fit'], sources['flux'], rtol=1e-1)
         assert_array_equal(result_tab['id'], sources['id'])
         assert_array_equal(result_tab['group_id'], sources['group_id'])
@@ -177,10 +176,10 @@ def test_psf_photometry_oneiter(sigma_psf, sources):
     img_shape = (32, 32)
     # generate image with read-out noise (Gaussian) and
     # background noise (Poisson)
-    image = (make_gaussian_sources_image(img_shape, sources) +
-             make_noise_image(img_shape, type='poisson', mean=6.,
+    image = (make_gaussian_prf_sources_image(img_shape, sources) +
+             make_noise_image(img_shape, distribution='poisson', mean=6.,
                               random_state=1) +
-             make_noise_image(img_shape, type='gaussian', mean=0.,
+             make_noise_image(img_shape, distribution='gaussian', mean=0.,
                               stddev=2., random_state=1))
     cp_image = image.copy()
 
@@ -198,8 +197,8 @@ def test_psf_photometry_oneiter(sigma_psf, sources):
                 np.sqrt(sources['flux'])).all()
         assert (result_tab['flux_unc'] < 1.96 *
                 np.sqrt(sources['flux'])).all()
-        assert_allclose(result_tab['x_fit'], sources['x_mean'], rtol=1e-1)
-        assert_allclose(result_tab['y_fit'], sources['y_mean'], rtol=1e-1)
+        assert_allclose(result_tab['x_fit'], sources['x_0'], rtol=1e-1)
+        assert_allclose(result_tab['y_fit'], sources['y_0'], rtol=1e-1)
         assert_allclose(result_tab['flux_fit'], sources['flux'], rtol=1e-1)
         assert_array_equal(result_tab['id'], sources['id'])
         assert_array_equal(result_tab['group_id'], sources['group_id'])
@@ -209,8 +208,8 @@ def test_psf_photometry_oneiter(sigma_psf, sources):
         phot_proc.psf_model.x_0.fixed = True
         phot_proc.psf_model.y_0.fixed = True
 
-        pos = Table(names=['x_0', 'y_0'], data=[sources['x_mean'],
-                                                sources['y_mean']])
+        pos = Table(names=['x_0', 'y_0'], data=[sources['x_0'],
+                                                sources['y_0']])
         cp_pos = pos.copy()
 
         result_tab = phot_proc(image, pos)
@@ -219,8 +218,8 @@ def test_psf_photometry_oneiter(sigma_psf, sources):
         assert 'y_0_unc' not in result_tab.colnames
         assert (result_tab['flux_unc'] < 1.96 *
                 np.sqrt(sources['flux'])).all()
-        assert_array_equal(result_tab['x_fit'], sources['x_mean'])
-        assert_array_equal(result_tab['y_fit'], sources['y_mean'])
+        assert_array_equal(result_tab['x_fit'], sources['x_0'])
+        assert_array_equal(result_tab['y_fit'], sources['y_0'])
         assert_allclose(result_tab['flux_fit'], sources['flux'], rtol=1e-1)
         assert_array_equal(result_tab['id'], sources['id'])
         assert_array_equal(result_tab['group_id'], sources['group_id'])
@@ -313,8 +312,8 @@ def test_finder_positions_warning():
     positions['x_0'] = [12.8, 18.2, 25.3]
     positions['y_0'] = [15.7, 16.5, 25.1]
 
-    image = (make_gaussian_sources_image((32, 32), sources1) +
-             make_noise_image((32, 32), type='poisson', mean=6.,
+    image = (make_gaussian_prf_sources_image((32, 32), sources1) +
+             make_noise_image((32, 32), distribution='poisson', mean=6.,
                               random_state=1))
 
     with catch_warnings(AstropyUserWarning):
@@ -335,10 +334,10 @@ def test_aperture_radius():
 
     # generate image with read-out noise (Gaussian) and
     # background noise (Poisson)
-    image = (make_gaussian_sources_image(img_shape, sources1) +
-             make_noise_image(img_shape, type='poisson', mean=6.,
+    image = (make_gaussian_prf_sources_image(img_shape, sources1) +
+             make_noise_image(img_shape, distribution='poisson', mean=6.,
                               random_state=1) +
-             make_noise_image(img_shape, type='gaussian', mean=0.,
+             make_noise_image(img_shape, distribution='gaussian', mean=0.,
                               stddev=2., random_state=1))
 
     basic_phot_obj = make_psf_photometry_objs()[0]
@@ -488,7 +487,8 @@ def test_psf_boundary():
 @pytest.mark.skipif('not HAS_SCIPY')
 def test_aperture_radius_value_error():
     """
-    Test psf_photometry with discrete PRF model at the boundary of the data.
+    Test that a ValueError is raised for tabular PSF models when
+    aperture_radius is not defined.
     """
 
     prf = DiscretePRF(test_psf, subsampling=1)
@@ -497,11 +497,13 @@ def test_aperture_radius_value_error():
                                     bkg_estimator=None, psf_model=prf,
                                     fitshape=7)
 
-    intab = Table(data=[[1], [1]], names=['x_0', 'y_0'])
-    with pytest.raises(ValueError) as err:
-        basic_phot(image=image, init_guesses=intab)
+    with pytest.raises(ValueError):
+        basic_phot(image=image)
 
-    assert 'aperture_radius is None' in str(err.value)
+    # with initial guesses, but without a "flux_0" column
+    intab = Table(data=[[1], [1]], names=['x_0', 'y_0'])
+    with pytest.raises(ValueError):
+        basic_phot(image=image, init_guesses=intab)
 
 
 @pytest.mark.skipif('not HAS_SCIPY')
@@ -555,9 +557,8 @@ def test_psf_photometry_gaussian2(renormalize_psf):
     f = basic_phot(image=image, init_guesses=INTAB)
 
     for n in ['x', 'y']:
-        assert_allclose(f[n + '_0'], f[n + '_fit'], rtol=1e-3)
-    # flux error worse, because of integration scheme ?
-    assert_allclose(f['flux_0'], f['flux_fit'], rtol=1)
+        assert_allclose(f[n + '_0'], f[n + '_fit'], rtol=1e-1)
+    assert_allclose(f['flux_0'], f['flux_fit'], rtol=1e-1)
 
 
 @pytest.mark.skipif('not HAS_SCIPY')
@@ -580,7 +581,7 @@ def test_psf_photometry_moffat():
     for n in ['x', 'y']:
         assert_allclose(f[n + '_0'], f[n + '_fit'], rtol=1e-3)
     # image was created with a gaussian, so flux won't match exactly
-    assert_allclose(f['flux_0'], f['flux_fit'], rtol=1)
+    assert_allclose(f['flux_0'], f['flux_fit'], rtol=1e-1)
 
 
 @pytest.mark.skipif('not HAS_SCIPY')
