@@ -1,19 +1,22 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+"""
+Tests for the detect module.
+"""
 
-import numpy as np
-from numpy.testing import assert_array_equal, assert_allclose
-import pytest
-
-from astropy.tests.helper import catch_warnings
-from astropy.utils.exceptions import AstropyUserWarning
 from astropy.convolution import Gaussian2DKernel
 from astropy.stats import gaussian_fwhm_to_sigma
+from astropy.tests.helper import catch_warnings
+from astropy.utils.exceptions import AstropyUserWarning
+import numpy as np
+from numpy.testing import assert_allclose, assert_array_equal
+import pytest
 
+from ...utils.exceptions import NoDetectionsWarning
 from ..detect import detect_sources, make_source_mask
 from ...datasets import make_4gaussians_image
 
 try:
-    import scipy    # noqa
+    import scipy  # noqa
     HAS_SCIPY = True
 except ImportError:
     HAS_SCIPY = False
@@ -24,8 +27,7 @@ class TestDetectSources:
     def setup_class(self):
         self.data = np.array([[0, 1, 0], [0, 2, 0],
                               [0, 0, 0]]).astype(np.float)
-        self.ref1 = np.array([[0, 0, 0], [0, 0, 0], [0, 0, 0]])
-        self.ref2 = np.array([[0, 1, 0], [0, 1, 0], [0, 0, 0]])
+        self.refdata = np.array([[0, 1, 0], [0, 1, 0], [0, 0, 0]])
 
         fwhm2sigma = 1.0 / (2.0 * np.sqrt(2.0 * np.log(2.0)))
         filter_kernel = Gaussian2DKernel(2. * fwhm2sigma, x_size=3, y_size=3)
@@ -36,13 +38,15 @@ class TestDetectSources:
         """Test basic detection."""
 
         segm = detect_sources(self.data, threshold=0.9, npixels=2)
-        assert_array_equal(segm.data, self.ref2)
+        assert_array_equal(segm.data, self.refdata)
 
     def test_small_sources(self):
         """Test detection where sources are smaller than npixels size."""
 
-        segm = detect_sources(self.data, threshold=0.9, npixels=5)
-        assert_array_equal(segm.data, self.ref1)
+        with catch_warnings(NoDetectionsWarning) as warning_lines:
+            detect_sources(self.data, threshold=0.9, npixels=5)
+            assert warning_lines[0].category == NoDetectionsWarning
+            assert 'No sources were found.' in str(warning_lines[0].message)
 
     def test_npixels(self):
         """
@@ -57,9 +61,9 @@ class TestDetectSources:
         data[3:, 3] = 2
 
         segm = detect_sources(data, 0, npixels=8)
-        assert(segm.nlabels == 1)
+        assert segm.nlabels == 1
         segm = detect_sources(data, 0, npixels=9)
-        assert(segm.nlabels == 1)
+        assert segm.nlabels == 1
 
         data = np.zeros((8, 8))
         data[0:4, 0] = 1
@@ -71,23 +75,27 @@ class TestDetectSources:
         npixels = np.arange(9, 14)
         for npixels in np.arange(9, 14):
             segm = detect_sources(data, 0, npixels=npixels)
-            assert(segm.nlabels == 1)
-            assert(segm.areas[0] == 13)
+            assert segm.nlabels == 1
+            assert segm.areas[0] == 13
 
-        segm = detect_sources(data, 0, npixels=14)
-        assert(segm.nlabels == 0)
+        with catch_warnings(NoDetectionsWarning) as warning_lines:
+            detect_sources(data, 0, npixels=14)
+            assert warning_lines[0].category == NoDetectionsWarning
+            assert 'No sources were found.' in str(warning_lines[0].message)
 
     def test_zerothresh(self):
         """Test detection with zero threshold."""
 
         segm = detect_sources(self.data, threshold=0., npixels=2)
-        assert_array_equal(segm.data, self.ref2)
+        assert_array_equal(segm.data, self.refdata)
 
     def test_zerodet(self):
-        """Test detection with large snr_threshold giving no detections."""
+        """Test detection with large threshold giving no detections."""
 
-        segm = detect_sources(self.data, threshold=7, npixels=2)
-        assert_array_equal(segm.data, self.ref1)
+        with catch_warnings(NoDetectionsWarning) as warning_lines:
+            detect_sources(self.data, threshold=7, npixels=2)
+            assert warning_lines[0].category == NoDetectionsWarning
+            assert 'No sources were found.' in str(warning_lines[0].message)
 
     def test_8connectivity(self):
         """Test detection with connectivity=8."""
@@ -154,7 +162,7 @@ class TestDetectSources:
     def test_mask(self):
         data = np.zeros((11, 11))
         data[3:8, 3:8] = 5.
-        mask = np.zeros_like(data, dtype=bool)
+        mask = np.zeros(data.shape, dtype=bool)
         mask[4:6, 4:6] = True
         segm1 = detect_sources(data, 1., 1.)
         segm2 = detect_sources(data, 1., 1., mask=mask)
@@ -182,3 +190,7 @@ class TestMakeSourceMask:
         kernel = Gaussian2DKernel(sigma, x_size=3, y_size=3)
         mask2 = make_source_mask(self.data, 5, 10, filter_kernel=kernel)
         assert_allclose(mask1, mask2)
+
+    def test_no_detections(self):
+        mask = make_source_mask(self.data, 100, 100)
+        assert np.count_nonzero(mask) == 0
