@@ -1,16 +1,15 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+"""
+This module provides tools for interpolating data.
+"""
 
-import warnings
-
-import numpy as np
 from astropy.utils import deprecated
-from astropy.utils.exceptions import AstropyUserWarning
+import numpy as np
 
-
-__all__ = ['ShepardIDWInterpolator', 'interpolate_masked_data',
-           'mask_to_mirrored_num']
+__all__ = ['ShepardIDWInterpolator', 'mask_to_mirrored_num']
 
 __doctest_requires__ = {('ShepardIDWInterpolator'): ['scipy']}
+__doctest_skip__ = ['mask_to_mirrored_num']
 
 
 class ShepardIDWInterpolator:
@@ -91,9 +90,9 @@ class ShepardIDWInterpolator:
         >>> x = np.random.random(100)
         >>> y = np.sin(x)
         >>> f = idw(x, y)
-        >>> f(0.4)    # doctest: +FLOAT_CMP
+        >>> f(0.4)  # doctest: +FLOAT_CMP
         0.38862424043228855
-        >>> np.sin(0.4)   # doctest: +FLOAT_CMP
+        >>> np.sin(0.4)  # doctest: +FLOAT_CMP
         0.3894183423086505
 
         >>> xi = np.random.random(4)
@@ -285,92 +284,7 @@ class ShepardIDWInterpolator:
             return interp_values
 
 
-@deprecated('0.4')
-def interpolate_masked_data(data, mask, error=None, background=None):
-    """
-    Interpolate over masked pixels in data and optional error or
-    background images.
-
-    The value of masked pixels are replaced by the mean value of the
-    connected neighboring non-masked pixels.  This function is intended
-    for single, isolated masked pixels (e.g. hot/warm pixels).
-
-    Parameters
-    ----------
-    data : array_like or `~astropy.units.Quantity`
-        The data array.
-
-    mask : array_like (bool)
-        A boolean mask, with the same shape as ``data``, where a `True`
-        value indicates the corresponding element of ``data`` is masked.
-
-    error : array_like or `~astropy.units.Quantity`, optional
-        The pixel-wise Gaussian 1-sigma errors of the input ``data``.
-        ``error`` must have the same shape as ``data``.
-
-    background : array_like, or `~astropy.units.Quantity`, optional
-        The pixel-wise background level of the input ``data``.
-        ``background`` must have the same shape as ``data``.
-
-    Returns
-    -------
-    data : `~numpy.ndarray` or `~astropy.units.Quantity`
-        Input ``data`` with interpolated masked pixels.
-
-    error : `~numpy.ndarray` or `~astropy.units.Quantity`
-        Input ``error`` with interpolated masked pixels.  `None` if
-        input ``error`` is not input.
-
-    background : `~numpy.ndarray` or `~astropy.units.Quantity`
-        Input ``background`` with interpolated masked pixels.  `None` if
-        input ``background`` is not input.
-    """
-
-    if data.shape != mask.shape:
-        raise ValueError('data and mask must have the same shape')
-
-    data_out = np.copy(data)    # do not alter input data
-    mask_idx = mask.nonzero()
-
-    if mask_idx[0].size == 0:
-        raise ValueError('All items in data are masked')
-
-    for x in zip(*mask_idx):
-        X = np.array([[max(x[i] - 1, 0), min(x[i] + 1, data.shape[i] - 1)]
-                      for i in range(len(data.shape))])
-        goodpix = ~mask[X]
-
-        if not np.any(goodpix):
-            warnings.warn('The masked pixel at "{}" is completely '
-                          'surrounded by (connected) masked pixels, '
-                          'thus unable to interpolate'.format(x,),
-                          AstropyUserWarning)
-            continue
-
-        data_out[x] = np.mean(data[X][goodpix])
-
-        if background is not None:
-            if background.shape != data.shape:
-                raise ValueError('background and data must have the same '
-                                 'shape')
-            background_out = np.copy(background)
-            background_out[x] = np.mean(background[X][goodpix])
-        else:
-            background_out = None
-
-        if error is not None:
-            if error.shape != data.shape:
-                raise ValueError('error and data must have the same '
-                                 'shape')
-            error_out = np.copy(error)
-            error_out[x] = np.sqrt(np.mean(error[X][goodpix]**2))
-        else:
-            error_out = None
-
-    return data_out, error_out, background_out
-
-
-def mask_to_mirrored_num(image, mask_image, center_position, bbox=None):
+def _mask_to_mirrored_num(image, mask_image, center_position, bbox=None):
     """
     Replace masked pixels with the value of the pixel mirrored across a
     given ``center_position``.  If the mirror pixel is unavailable (i.e.
@@ -399,20 +313,6 @@ def mask_to_mirrored_num(image, mask_image, center_position, bbox=None):
     -------
     result : `numpy.ndarray`, 2D
         A 2D array with replaced masked pixels.
-
-    Examples
-    --------
-    >>> import numpy as np
-    >>> from photutils.utils import mask_to_mirrored_num
-    >>> image = np.arange(16).reshape(4, 4)
-    >>> mask = np.zeros_like(image, dtype=bool)
-    >>> mask[0, 0] = True
-    >>> mask[1, 1] = True
-    >>> mask_to_mirrored_num(image, mask, (1.5, 1.5))
-    array([[15,  1,  2,  3],
-           [ 4, 10,  6,  7],
-           [ 8,  9, 10, 11],
-           [12, 13, 14, 15]])
     """
 
     if bbox is None:
@@ -448,3 +348,53 @@ def mask_to_mirrored_num(image, mask_image, center_position, bbox=None):
     outimage[bbox[2]:bbox[3]+1, bbox[0]:bbox[1]+1] = subdata
 
     return outimage
+
+
+@deprecated(0.7)
+def mask_to_mirrored_num(image, mask_image, center_position, bbox=None):
+    """
+    Replace masked pixels with the value of the pixel mirrored across a
+    given ``center_position``.  If the mirror pixel is unavailable (i.e.
+    itself masked or outside of the image), then the masked pixel value
+    is set to zero.
+
+    Parameters
+    ----------
+    image : `numpy.ndarray`, 2D
+        The 2D array of the image.
+
+    mask_image : array-like, bool
+        A boolean mask with the same shape as ``image``, where a `True`
+        value indicates the corresponding element of ``image`` is
+        considered bad.
+
+    center_position : 2-tuple
+        (x, y) center coordinates around which masked pixels will be
+        mirrored.
+
+    bbox : list, tuple, `numpy.ndarray`, optional
+        The bounding box (x_min, x_max, y_min, y_max) over which to
+        replace masked pixels.
+
+    Returns
+    -------
+    result : `numpy.ndarray`, 2D
+        A 2D array with replaced masked pixels.
+
+    Examples
+    --------
+    >>> import numpy as np
+    >>> from photutils.utils import mask_to_mirrored_num
+    >>> image = np.arange(16).reshape(4, 4)
+    >>> mask = np.zeros(image.shape, dtype=bool)
+    >>> mask[0, 0] = True
+    >>> mask[1, 1] = True
+    >>> mask_to_mirrored_num(image, mask, (1.5, 1.5))
+    array([[15,  1,  2,  3],
+           [ 4, 10,  6,  7],
+           [ 8,  9, 10, 11],
+           [12, 13, 14, 15]])
+    """
+
+    return _mask_to_mirrored_num(image, mask_image, center_position,
+                                 bbox=bbox)
