@@ -1,17 +1,15 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+"""
+This module provides tools to return the installed astropy and photutils
+versions.
+"""
 
-import abc
-
-from astropy.utils.misc import InheritDocstrings
-
+from astropy.utils import deprecated
 
 __all__ = ['get_version_info']
 
 
-class _ABCMetaAndInheritDocstrings(InheritDocstrings, abc.ABCMeta):
-    pass
-
-
+@deprecated('0.7')
 def get_version_info():
     """
     Return astropy and photutils versions.
@@ -22,6 +20,19 @@ def get_version_info():
         The astropy and photutils versions.
     """
 
+    return _get_version_info()
+
+
+def _get_version_info():
+    """
+    Return astropy and photutils versions.
+
+    Returns
+    -------
+    result : str
+        The astropy and photutils versions.
+    """
+
     from astropy import __version__
     astropy_version = __version__
 
